@@ -1,13 +1,11 @@
 # coding=utf-8
-"""
-Lightweight integration and denormalisation using events (signals).
-"""
+"""Lightweight integration and denormalisation using events (signals)."""
 
-from __future__ import absolute_import, print_function
-
-from blinker import ANY
+from __future__ import absolute_import, print_function, unicode_literals
 
 from abilian.core.signals import activity
+from blinker import ANY
+
 from abilian.sbe.apps.documents.models import Document
 
 from .models import Community
@@ -24,7 +22,7 @@ def update_community(sender, verb, actor, object, target=None):
         community.touch()
 
         if isinstance(object, Document):
-            if verb == 'post':
+            if verb == "post":
                 community.document_count += 1
-            elif verb == 'delete':
+            elif verb == "delete":
                 community.document_count -= 1
