@@ -1,7 +1,6 @@
 # coding=utf-8
-"""
-"""
-from __future__ import absolute_import, print_function
+""""""
+from __future__ import absolute_import, print_function, unicode_literals
 
 from blinker.base import Namespace
 
@@ -12,8 +11,8 @@ ns = Namespace()
 
 #: sent when membership is set. Sender is community, arguments are:
 #: :class:`.models.Membership` instance, :bool:`is_new`
-membership_set = ns.signal('membership_set')
+membership_set = ns.signal("membership_set")
 
 #: sent just before membership is removed. Sender is community, arguments:
 # :class:`.models.Membership` instance
-membership_removed = ns.signal('membership_removed')
+membership_removed = ns.signal("membership_removed")
