@@ -1,7 +1,5 @@
 # coding=utf-8
-"""
-Folders / Documents module
-"""
+"""Folders / Documents module."""
 from __future__ import absolute_import
 
 from abilian.sbe.extension import sbe
@@ -12,7 +10,7 @@ def register_plugin(app):
 
     from .views import blueprint
     from .models import setup_listener
-    from .commands import manager
+    from .commands import manager  # pylint: disable=bad-python3-import
     from . import signals  # noqa
     from . import lock
 
@@ -20,7 +18,7 @@ def register_plugin(app):
     setup_listener()
 
     # set default lock lifetime
-    app.config.setdefault('SBE_LOCK_LIFETIME', lock.DEFAULT_LIFETIME)
+    app.config.setdefault("SBE_LOCK_LIFETIME", lock.DEFAULT_LIFETIME)
 
     if app.script_manager:
-        app.script_manager.add_command('documents', manager)
+        app.script_manager.add_command("documents", manager)
