@@ -1,24 +1,20 @@
 # coding=utf-8
-"""
-"""
-from __future__ import absolute_import, print_function
+""""""
+from __future__ import absolute_import, print_function, unicode_literals
 
 from datetime import datetime, timedelta
 
 import dateutil.parser
+from abilian.core.util import utcnow
 from flask import current_app
 from flask_login import current_user
 from six import raise_from, text_type
 
-from abilian.core.util import utcnow
-
 DEFAULT_LIFETIME = 3600
 
 
 class Lock(object):
-    """
-    Represent a lock on a document
-    """
+    """Represent a lock on a document."""
 
     def __init__(self, user_id, user, date, *args, **kwargs):
         self.user_id = user_id
@@ -27,8 +23,7 @@ class Lock(object):
             try:
                 date = dateutil.parser.parse(date)
             except Exception as e:
-                raise_from(
-                    ValueError('Error parsing date: {!r}'.format(date)), e)
+                raise_from(ValueError("Error parsing date: {!r}".format(date)), e)
 
         self.date = date
 
@@ -37,20 +32,21 @@ class Lock(object):
         return Lock(current_user.id, text_type(current_user), utcnow())
 
     def as_dict(self):
-        """Return a dict suitable for serialization to JSON.
-        """
-        return dict(
-            user_id=self.user_id, user=self.user, date=self.date.isoformat())
+        """Return a dict suitable for serialization to JSON."""
+        return {
+            "user_id": self.user_id,
+            "user": self.user,
+            "date": self.date.isoformat(),
+        }
 
     @staticmethod
     def from_dict(d):
-        """Deserialize from a `dict` created by :meth:`as_dict`.
-        """
+        """Deserialize from a `dict` created by :meth:`as_dict`."""
         return Lock(**d)
 
     @property
     def lifetime(self):
-        return current_app.config.get('SBE_LOCK_LIFETIME', DEFAULT_LIFETIME)
+        return current_app.config.get("SBE_LOCK_LIFETIME", DEFAULT_LIFETIME)
 
     @property
     def expired(self):
