@@ -1,11 +1,9 @@
 # coding=utf-8
-"""
-"""
-from __future__ import absolute_import, print_function
+""""""
+from __future__ import absolute_import, print_function, unicode_literals
 
 import sqlalchemy as sa
-
-from abilian.services.security import READ, security
+from abilian.services.security import READ, Permission, security
 
 from .models import CmisObject, Document, Folder
 
@@ -15,10 +13,8 @@ class SecurityException(Exception):
 
 
 class Repository(object):
-    """
-    A simple document repository, implementing the basic functionalities of the
-    CMIS model.
-    """
+    """A simple document repository, implementing the basic functionalities of
+    the CMIS model."""
 
     def __init__(self, app=None):
         if app is not None:
@@ -26,7 +22,7 @@ class Repository(object):
 
     def init_app(self, app):
         self.app = app
-        app.extensions['content_repository'] = self
+        app.extensions["content_repository"] = self
 
     @property
     def root_folder(self):
@@ -35,13 +31,12 @@ class Repository(object):
             return folder
 
         # Should only happen during tests
-        folder = Folder(title=u'root')
+        folder = Folder(title="root")
         return folder
 
     def get_object(self, id=None, path=None):
-        """
-        Get the CMIS object (document or folder) with either the given `id` or the
-        given `path`.
+        """Get the CMIS object (document or folder) with either the given `id`
+        or the given `path`.
 
         Returns None if the object doesn't exist.
         """
@@ -133,7 +128,7 @@ class Repository(object):
             raise Exception("Can't delete root folder.")
 
         session = sa.orm.object_session(obj)
-        setattr(obj, '__path_before_delete', obj.path)  # for audit log.
+        setattr(obj, "__path_before_delete", obj.path)  # for audit log.
         parent = obj.parent
         collection = parent.subfolders if obj.is_folder else parent.documents
         session.delete(obj)
@@ -158,13 +153,12 @@ class Repository(object):
     # Security / access rights
     #
     def has_permission(self, user, permission, obj):
+        assert isinstance(permission, Permission)
         return security.has_permission(user, permission, obj, inherit=True)
 
     def has_access(self, user, obj):
-        """
-        Checks that user has actual right to reach this object, 'read' permission
-        on each of object's parents.
-        """
+        """Checks that user has actual right to reach this object, 'read'
+        permission on each of object's parents."""
         current = obj
         while current.parent is not None:
             if not self.has_permission(user, READ, current):
