@@ -1,4 +1,8 @@
-from os.path import dirname
+# coding=utf-8
+from __future__ import absolute_import, division, print_function, \
+    unicode_literals
+
+from pathlib import Path
 
 from lxml import etree
 
@@ -7,21 +11,21 @@ from ..webdav.xml import MultiStatus, Propfind
 
 
 def test_propfind_sample1():
-    xml = open(dirname(__file__) + "/data/propfind1.xml").read()
+    xml = (Path(__file__).parent / "data" / "propfind1.xml").open("rb").read()
     propfind = Propfind(xml)
-    assert propfind.mode == 'prop'
+    assert propfind.mode == "prop"
 
 
 def test_propfind_sample2():
-    xml = open(dirname(__file__) + "/data/propfind2.xml").read()
+    xml = (Path(__file__).parent / "data" / "propfind2.xml").open("rb").read()
     propfind = Propfind(xml)
-    assert propfind.mode == 'prop'
+    assert propfind.mode == "prop"
 
 
 def test_propfind_sample3():
-    xml = open(dirname(__file__) + "/data/propfind3.xml").read()
+    xml = (Path(__file__).parent / "data" / "propfind3.xml").open("rb").read()
     propfind = Propfind(xml)
-    assert propfind.mode == 'allprop'
+    assert propfind.mode == "allprop"
 
 
 def test_empty_multistatus():
@@ -33,7 +37,6 @@ def test_empty_multistatus():
 
 
 def test_multistatus():
-
     class Obj(object):
         pass
 
