@@ -19,6 +19,7 @@ import whoosh.query as wq
 from abilian.core.extensions import db
 from abilian.core.models.subjects import Group, User
 from abilian.core.signals import activity
+from abilian.core.util import unwrap
 from abilian.i18n import _, _n
 from abilian.services import get_service
 from abilian.services.security import READ, WRITE, Role, security
@@ -35,8 +36,7 @@ from werkzeug.exceptions import InternalServerError
 from xlwt import Workbook, easyxf
 
 from abilian.sbe.apps.communities.views import default_view_kw
-from abilian.sbe.apps.documents.models import Document, Folder, icon_for, \
-    icon_url
+from abilian.sbe.apps.documents.models import Document, Folder, icon_for, icon_url
 from abilian.sbe.apps.documents.repository import repository
 from abilian.sbe.apps.documents.search import reindex_tree
 
@@ -487,7 +487,7 @@ def iter_permissions(folder, user):
     """Iterator returning permissions settings on folder and its subfolders
     tree."""
     if not security.has_permission(user, "manage", folder, inherit=True):
-        raise StopIteration
+        return
 
     community = folder.path
     local_roles = frozenset(folder.get_local_roles_assignments())
@@ -507,8 +507,8 @@ def iter_permissions(folder, user):
         is_user = isinstance(principal, User)
         item_key = [is_user]  # type: List[Any]
         if is_user:
-            last_name = principal.last_name if principal.last_name else ""
-            first_name = principal.first_name if principal.first_name else ""
+            last_name = principal.last_name or ""
+            first_name = principal.first_name or ""
             item_key.append(last_name.lower())
             item_key.append(first_name.lower())
         else:
@@ -619,35 +619,39 @@ def explore_archive(fd, uncompress=False):
     """
     if not uncompress:
         yield [], fd
-        raise StopIteration
+        return
 
-    if is_zipfile(fd):
-        with ZipFile(fd, "r") as archive:
-            for zipinfo in archive.infolist():
-                filename = zipinfo.filename
-                if isinstance(filename, bytes):
-                    # not unicode: try to convert from utf-8 (OSX case: unicode flag not
-                    # set), then legacy cp437
-                    # http://stackoverflow.com/questions/13261347/correctly-decoding-zip-entry-file-names-cp437-utf-8-or
-                    try:
-                        filename = filename.decode("utf-8")
-                    except UnicodeDecodeError:
-                        filename = filename.decode("cp437")
-
-                if any(
-                    pattern.match(filename) is not None
-                    for pattern in ARCHIVE_IGNORE_FILES
-                ):
-                    continue
-
-                filepath = filename.split("/")
-                filename = filepath.pop()
-                zip_fd = archive.open(zipinfo, "r")
-                setattr(zip_fd, "filename", filename)
-                setattr(zip_fd, "content_type", None)
-                yield filepath, zip_fd
-    else:
+    if not is_zipfile(fd):
         yield [], fd
+        return
+
+    # XXX: workaround https://bugs.python.org/issue26175 in Python 3.7
+    # TODO: Remove when it's fixed
+    fd.seekable = lambda: True
+
+    with ZipFile(fd, "r") as archive:
+        for zipinfo in archive.infolist():
+            filename = zipinfo.filename
+            if isinstance(filename, bytes):
+                # not unicode: try to convert from utf-8 (OSX case: unicode flag not
+                # set), then legacy cp437
+                # http://stackoverflow.com/questions/13261347/correctly-decoding-zip-entry-file-names-cp437-utf-8-or
+                try:
+                    filename = filename.decode("utf-8")
+                except UnicodeDecodeError:
+                    filename = filename.decode("cp437")
+
+            if any(
+                pattern.match(filename) is not None for pattern in ARCHIVE_IGNORE_FILES
+            ):
+                continue
+
+            filepath = filename.split("/")
+            filename = filepath.pop()
+            zip_fd = archive.open(zipinfo, "r")
+            setattr(zip_fd, "filename", filename)
+            setattr(zip_fd, "content_type", None)
+            yield filepath, zip_fd
 
 
 def upload_new(folder):
@@ -753,7 +757,7 @@ def delete_multiple(folder):
     folders, docs = get_selected_objects(folder)
 
     for obj in docs + folders:
-        app = current_app._get_current_object()
+        app = unwrap(current_app)
         community = g.community._model
         activity.send(app, actor=g.user, verb="delete", object=obj, target=community)
         repository.delete_object(obj)
@@ -788,6 +792,8 @@ def delete_multiple(folder):
 
 def move_multiple(folder):
     folders, docs = get_selected_objects(folder)
+    objects = folder + docs
+
     count_f = len(folders)
     count_d = len(docs)
     current_folder_url = url_for(folder)
@@ -828,7 +834,7 @@ def move_multiple(folder):
         )
         return redirect(current_folder_url)
 
-    for item in itertools.chain(folders, docs):
+    for item in objects:
         # FIXME: maybe too brutal
         check_write_access(item)
 
@@ -847,14 +853,7 @@ def move_multiple(folder):
             return redirect(url_for(folder))
         f = f.parent
 
-    exist_in_dest = []
-    for item in itertools.chain(folders, docs):
-        try:
-            with db.session.begin_nested():
-                item.parent = target_folder
-        except sa.exc.IntegrityError:
-            exist_in_dest.append(item)
-
+    exist_in_dest = objects_which_exist_in_dest(objects, target_folder)
     if exist_in_dest:
         # items existing in destination: cancel operation
         db.session.rollback()
@@ -884,6 +883,17 @@ def move_multiple(folder):
     return redirect(url_for(folder))
 
 
+def objects_which_exist_in_dest(objects, dest):
+    exist_in_dest = []
+    for item in objects:
+        try:
+            with db.session.begin_nested():
+                item.parent = dest
+        except sa.exc.IntegrityError:
+            exist_in_dest.append(item)
+    return exist_in_dest
+
+
 def create_subfolder(folder):
     check_write_access(folder)
 
@@ -957,16 +967,18 @@ def descendants_view(folder_id):
     root_path_ids = folder._indexable_parent_ids + "/{}".format(folder.id)
     index_service = get_service("indexing")
 
-    # yapf: disable
-    filters = wq.And([
-        wq.Term('community_id', folder.community.id),
-        wq.Term('parent_ids', root_path_ids),
-        wq.Or([
-            wq.Term('object_type', Folder.entity_type),
-            wq.Term('object_type', Document.entity_type),
-        ]),
-    ])
-    # yapf: enable
+    filters = wq.And(
+        [
+            wq.Term("community_id", folder.community.id),
+            wq.Term("parent_ids", root_path_ids),
+            wq.Or(
+                [
+                    wq.Term("object_type", Folder.entity_type),
+                    wq.Term("object_type", Document.entity_type),
+                ]
+            ),
+        ]
+    )
 
     results = index_service.search("", filter=filters, limit=None)
     by_path = {}
