@@ -1,28 +1,28 @@
-from __future__ import print_function
+# coding=utf-8
+from __future__ import absolute_import, print_function, unicode_literals
 
 import os.path
 import uuid
 
-from flask import Blueprint, current_app, request
-from flask.ext.login import current_user
+from abilian.core.extensions import db
+from abilian.services import get_service
+from flask import Blueprint, request
+from flask_login import current_user
 from lxml.etree import XMLSyntaxError
 from werkzeug.datastructures import Headers
 from werkzeug.exceptions import Forbidden, NotFound
 from werkzeug.wrappers import BaseResponse as Response
 
-from abilian.core.extensions import db
-
 from .. import repository
-from .constants import (DAV_PROPS, HTTP_BAD_REQUEST, HTTP_CONFLICT,
-                        HTTP_CREATED, HTTP_METHOD_NOT_ALLOWED,
-                        HTTP_MULTI_STATUS, HTTP_NO_CONTENT, HTTP_OK,
-                        HTTP_PRECONDITION_FAILED, OPTIONS)
+from .constants import DAV_PROPS, HTTP_BAD_REQUEST, HTTP_CONFLICT, \
+    HTTP_CREATED, HTTP_METHOD_NOT_ALLOWED, HTTP_MULTI_STATUS, \
+    HTTP_NO_CONTENT, HTTP_OK, HTTP_PRECONDITION_FAILED, OPTIONS
 from .xml import MultiStatus, Propfind
 
 webdav = Blueprint("webdav", __name__, url_prefix="/webdav")
 route = webdav.route
 
-__all__ = ['webdav']
+__all__ = ["webdav"]
 
 #
 # Utils
@@ -31,7 +31,6 @@ __all__ = ['webdav']
 
 # TODO: real logging
 class Logger(object):
-
     def debug(self, msg):
         print(msg)
 
@@ -42,23 +41,25 @@ log = Logger()
 # XXX: temporary debug info.
 @webdav.before_request
 def log_request():
-    litmus_msg = request.headers.get('X-Litmus')
+    litmus_msg = request.headers.get("X-Litmus")
     if litmus_msg:
-        print('')
-        print(78 * '#')
+        print("")
+        print(78 * "#")
         print(litmus_msg)
-        print('{} on {}'.format(request.method, request.path))
+        print("{} on {}".format(request.method, request.path))
 
 
 @webdav.before_request
 def only_admin():
-    if not current_app.services('security').has_role(current_user, "admin"):
+    security = get_service("security")
+
+    if not security.has_role(current_user, "admin"):
         raise Forbidden()
 
 
 @webdav.after_request
 def log_response(response):
-    print('Response: {}'.format(response))
+    print("Response: {}".format(response))
     return response
 
 
@@ -84,39 +85,43 @@ def get_object(path):
 @webdav.before_app_request
 def create_root_folder():
     # TODO: create root folder on repository startup instead.
-    #assert repository.root_folder
+    # assert repository.root_folder
     pass
 
 
 #
 # HTTP endpoints
 #
-@route('/', methods=['OPTIONS'], defaults={'path': '/'})
-@route('/<path:path>', methods=['OPTIONS'])
+@route("/", methods=["OPTIONS"], defaults={"path": "/"})
+@route("/<path:path>", methods=["OPTIONS"])
 def options(path):
-    headers = {'Content-Type': 'text/plain',
-               'Content-Length': '0',
-               'DAV': '1,2',
-               'MS-Author-Via': 'DAV',
-               'Allow': OPTIONS}
+    headers = {
+        "Content-Type": "text/plain",
+        "Content-Length": "0",
+        "DAV": "1,2",
+        "MS-Author-Via": "DAV",
+        "Allow": OPTIONS,
+    }
     print("Returning", headers)
     return "", HTTP_OK, headers
 
 
-@route('/', defaults={'path': '/'})
-@route('/<path:path>')
+@route("/", defaults={"path": "/"})
+@route("/<path:path>")
 def get(path):
     path = normpath(path)
 
     obj = get_object(path)
 
-    file_name = obj.file_name.encode('utf8')
-    headers = {'Content-Type': obj.content_type,
-               'Content-Disposition': 'attachment;filename=%s' % file_name}
+    file_name = obj.file_name.encode("utf8")
+    headers = {
+        "Content-Type": obj.content_type,
+        "Content-Disposition": "attachment;filename=%s" % file_name,
+    }
     return obj.content, HTTP_OK, headers
 
 
-@route('/<path:path>', methods=['MKCOL'])
+@route("/<path:path>", methods=["MKCOL"])
 def mkcol(path):
     path = normpath(path)
     parent_path, name = split_path(path)
@@ -137,7 +142,7 @@ def mkcol(path):
     return "", HTTP_CREATED, {}
 
 
-@route('/<path:path>', methods=['PUT'])
+@route("/<path:path>", methods=["PUT"])
 def put(path):
     path = normpath(path)
     parent_path, name = split_path(path)
@@ -162,7 +167,7 @@ def put(path):
     return "", status, {}
 
 
-@route('/<path:path>', methods=['DELETE'])
+@route("/<path:path>", methods=["DELETE"])
 def delete(path):
     path = normpath(path)
 
@@ -173,13 +178,13 @@ def delete(path):
     return "", HTTP_NO_CONTENT, {}
 
 
-@route("/<path:path>", methods=['COPY', 'MOVE'])
+@route("/<path:path>", methods=["COPY", "MOVE"])
 def copy_or_move(path):
     path = normpath(path)
-    dest = request.headers.get('destination')
-    dest_path = normpath(dest[len(request.url_root + "webdav"):])
+    dest = request.headers.get("destination")
+    dest_path = normpath(dest[len(request.url_root + "webdav") :])
     dest_parent_path, dest_name = split_path(dest_path)
-    overwrite = request.headers.get('overwrite')
+    overwrite = request.headers.get("overwrite")
 
     orig_obj = get_object(path)
 
@@ -197,7 +202,7 @@ def copy_or_move(path):
     if dest_folder is None:
         return "", HTTP_CONFLICT, {}
 
-    if request.method == 'COPY':
+    if request.method == "COPY":
         repository.copy_object(orig_obj, dest_folder, dest_name)
     else:
         if dest_folder == orig_obj.parent:
@@ -209,11 +214,11 @@ def copy_or_move(path):
     return "", status, {}
 
 
-@route('/', defaults={'path': '/'}, methods=['PROPFIND'])
-@route('/<path:path>', methods=['PROPFIND'])
+@route("/", defaults={"path": "/"}, methods=["PROPFIND"])
+@route("/<path:path>", methods=["PROPFIND"])
 def propfind(path):
     path = normpath(path)
-    depth = request.headers.get('depth', "1")
+    depth = request.headers.get("depth", "1")
 
     print(request.headers)
     print(request.data)
@@ -234,11 +239,11 @@ def propfind(path):
 
     print(m.to_string())
 
-    headers = {'Content-Type': 'text/xml'}
+    headers = {"Content-Type": "text/xml"}
     return m.to_string(), HTTP_MULTI_STATUS, headers
 
 
-@route('/<path:path>', methods=['LOCK'])
+@route("/<path:path>", methods=["LOCK"])
 def lock(path):
     path = normpath(path)
     obj = get_object(path)
@@ -253,7 +258,8 @@ def lock(path):
 
     token = repository.lock(obj)
 
-    xml = '''<?xml version="1.0" encoding="utf-8" ?>
+    xml = (
+        """<?xml version="1.0" encoding="utf-8" ?>
 <D:prop xmlns:D="DAV:">
     <D:lockdiscovery>
         <D:activelock>
@@ -267,46 +273,43 @@ def lock(path):
             </D:locktoken>
         </D:activelock>
     </D:lockdiscovery>
-</D:prop>''' % token
+</D:prop>"""
+        % token
+    )
 
-    hlist = [('Content-Type', 'text/xml'),
-             ('Lock-Token', '<urn:uuid:%s>' % token)]
+    hlist = [("Content-Type", "text/xml"), ("Lock-Token", "<urn:uuid:%s>" % token)]
 
-    return Response(xml,
-                    headers=Headers.linked(hlist))  # , status ='423 Locked'
-    """
-    public Response lock(@Context UriInfo uriInfo) throws Exception {
-        String token = null;
-        Prop prop = null;
-        if (backend.isLocked(doc.getRef())) {
-            if (!backend.canUnlock(doc.getRef())) {
-                return Response.status(423).build();
-            } else {
-                token = backend.getCheckoutUser(doc.getRef());
-                prop = new Prop(getLockDiscovery(doc, uriInfo));
-                return Response.ok().entity(prop).header("Lock-Token",
-                        "urn:uuid:" + token).build();
-            }
-        }
-
-        token = backend.lock(doc.getRef());
-        if (READONLY_TOKEN.equals(token)) {
-            return Response.status(423).build();
-        } else if (StringUtils.isEmpty(token)) {
-            return Response.status(400).build();
-        }
-
-        prop = new Prop(getLockDiscovery(doc, uriInfo));
-
-        backend.saveChanges();
-        return Response.ok().entity(prop).header("Lock-Token",
-                "urn:uuid:" + token).build();
-    }
-
-  """
+    return Response(xml, headers=Headers.linked(hlist))  # , status ='423 Locked'
+    # public Response lock(@Context UriInfo uriInfo) throws Exception {
+    #     String token = null;
+    #     Prop prop = null;
+    #     if (backend.isLocked(doc.getRef())) {
+    #         if (!backend.canUnlock(doc.getRef())) {
+    #             return Response.status(423).build();
+    #         } else {
+    #             token = backend.getCheckoutUser(doc.getRef());
+    #             prop = new Prop(getLockDiscovery(doc, uriInfo));
+    #             return Response.ok().entity(prop).header("Lock-Token",
+    #                     "urn:uuid:" + token).build();
+    #         }
+    #     }
+    #
+    #     token = backend.lock(doc.getRef());
+    #     if (READONLY_TOKEN.equals(token)) {
+    #         return Response.status(423).build();
+    #     } else if (StringUtils.isEmpty(token)) {
+    #         return Response.status(400).build();
+    #     }
+    #
+    #     prop = new Prop(getLockDiscovery(doc, uriInfo));
+    #
+    #     backend.saveChanges();
+    #     return Response.ok().entity(prop).header("Lock-Token",
+    #             "urn:uuid:" + token).build();
+    # }
 
 
-@route('/<path:path>', methods=['UNLOCK'])
+@route("/<path:path>", methods=["UNLOCK"])
 def unlock(path):
     path = normpath(path)
     obj = get_object(path)
@@ -320,19 +323,16 @@ def unlock(path):
             return "", HTTP_NO_CONTENT, {}
 
     return "", HTTP_NO_CONTENT, {}
-    """
-        if (backend.isLocked(doc.getRef())) {
-            if (!backend.canUnlock(doc.getRef())) {
-                return Response.status(423).build();
-            } else {
-                backend.unlock(doc.getRef());
-                backend.saveChanges();
-                return Response.status(HTTP_NO_CONTENT).build();
-            }
-        } else {
-            // TODO: return an error
-            return Response.status(HTTP_NO_CONTENT).build();
-        }
-
-
-  """
+    #     if (backend.isLocked(doc.getRef())) {
+    #         if (!backend.canUnlock(doc.getRef())) {
+    #             return Response.status(423).build();
+    #         } else {
+    #             backend.unlock(doc.getRef());
+    #             backend.saveChanges();
+    #             return Response.status(HTTP_NO_CONTENT).build();
+    #         }
+    #     } else {
+    #         // TODO: return an error
+    #         return Response.status(HTTP_NO_CONTENT).build();
+    #     }
+    #
