@@ -1,7 +1,7 @@
-"""Main views.
-"""
+# coding=utf-8
+"""Main views."""
 
-from __future__ import absolute_import, print_function
+from __future__ import absolute_import, print_function, unicode_literals
 
 from flask import Blueprint, render_template
 
