@@ -1,25 +1,25 @@
-"""
-The blueprint for this app.
-"""
+# coding=utf-8
+"""The blueprint for this app."""
 
-from __future__ import absolute_import, print_function
-
-from flask import Blueprint, redirect, render_template, url_for
+from __future__ import absolute_import, print_function, unicode_literals
 
 from abilian.core.extensions import db
 from abilian.core.util import get_params
+from flask import Blueprint, redirect, render_template, url_for
+
 from abilian.sbe.apps.wall.presenters import ActivityEntryPresenter
 from abilian.sbe.apps.wall.util import get_recent_entries
 
 from ..models import Message
 
-__all__ = ['social']
+__all__ = ["social"]
 
 MAX_LAST_USERS = 15
 MAX_MESSAGES = 15
 
 social = Blueprint(
-    "social", __name__, url_prefix='/social', template_folder='../templates')
+    "social", __name__, url_prefix="/social", template_folder="../templates"
+)
 route = social.route
 
 
@@ -28,7 +28,7 @@ def home():
     ctx = {}
     entries = get_recent_entries(num=50)
     entries = ActivityEntryPresenter.wrap_collection(entries)
-    ctx['activity_entries'] = entries
+    ctx["activity_entries"] = entries
 
     return render_template("social/home.html", **ctx)
 
@@ -38,11 +38,11 @@ def stream(stream_name):
     pass
 
 
-@route("/", methods=['POST'])
+@route("/", methods=["POST"])
 def share():
     # TODO: better error control / feedback
     d = get_params(Message.__editable__)
-    if not d.get('content'):
+    if not d.get("content"):
         return redirect(url_for(".home"))
 
     message = Message(**d)
