@@ -1,47 +1,53 @@
 # coding=utf-8
-"""
-"""
-from __future__ import absolute_import, print_function
+""""""
+from __future__ import absolute_import, print_function, unicode_literals
 
 import logging
 import pkgutil
 from cgi import escape
 
 import sqlalchemy as sa
-from flask import Response, current_app, flash, g, jsonify, redirect, \
-    render_template, request
-from six import text_type
-from sqlalchemy.sql.expression import and_, asc, desc, func, nullslast, or_
-from werkzeug.exceptions import InternalServerError
-
+import sqlalchemy.exc
+import sqlalchemy.orm
 from abilian.core.extensions import db
 from abilian.core.models.subjects import User
 from abilian.i18n import _, _l
-from abilian.sbe.apps.communities.models import Membership
-from abilian.sbe.apps.wall.presenters import ActivityEntryPresenter
-from abilian.sbe.apps.wall.views import get_recent_entries
+from abilian.services import get_service
 from abilian.web import url_for
 from abilian.web.filters import age
 from abilian.web.views import ObjectEdit, default_view
 from abilian.web.views.images import user_photo_url
+from flask import Response, flash, g, jsonify, redirect, render_template, \
+    request
+from six import text_type
+from sqlalchemy.sql.expression import and_, asc, desc, func, nullslast, or_
+from werkzeug.exceptions import InternalServerError
+
+from abilian.sbe.apps.communities.models import Membership
+from abilian.sbe.apps.wall.presenters import ActivityEntryPresenter
+from abilian.sbe.apps.wall.views import get_recent_entries
 
 from ..forms import UserProfileForm, UserProfileViewForm
 from .social import social
-from .util import Env
 
 logger = logging.getLogger(__name__)
 
-DEFAULT_USER_MUGSHOT = pkgutil.get_data('abilian.sbe',
-                                        'static/images/silhouette_unknown.png')
+DEFAULT_USER_MUGSHOT = pkgutil.get_data(
+    "abilian.sbe", "static/images/silhouette_unknown.png"
+)
 
 
 def make_tabs(user):
     return [
-        dict(id='profile', label=_(u'Profile'), link=url_for(user, tab='profile')),
+        {"id": "profile", "label": _("Profile"), "link": url_for(user, tab="profile")},
         # dict(id='conversations', label=_(u'Conversations'), link=url_for(user), is_online=True),
-        dict(id='documents', label=_(u'Documents'), link=url_for(user, tab='documents')),
-        dict(id='images', label=_(u'Images'), link=url_for(user, tab='images')),
-        dict(id='audit', label=_(u'Audit'), link=url_for(user, tab='audit')),
+        {
+            "id": "documents",
+            "label": _("Documents"),
+            "link": url_for(user, tab="documents"),
+        },
+        {"id": "images", "label": _("Images"), "link": url_for(user, tab="images")},
+        {"id": "audit", "label": _("Audit"), "link": url_for(user, tab="audit")},
     ]
 
 
@@ -53,17 +59,21 @@ def users():
         query = query.replace("%", " ")
         q = or_(
             User.first_name.like("%" + query + "%"),
-            User.last_name.like("%" + query + "%"))
+            User.last_name.like("%" + query + "%"),
+        )
         users = User.query.filter(q).limit(100).all()
     else:
         users = User.query.limit(100).all()
-    ctx = dict(users=users)
+    ctx = {"users": users}
     return render_template("social/users.html", **ctx)
 
 
 @social.route("/users/dt_json")
 def users_dt_json():
-    """JSON call to fill a DataTable. Needs some refactoring."""
+    """JSON call to fill a DataTable.
+
+    Needs some refactoring.
+    """
     args = request.args
 
     length = int(args.get("iDisplayLength", 0))
@@ -82,9 +92,9 @@ def users_dt_json():
         # TODO: gérer les accents
         filter = or_(
             func.lower(User.first_name).like("%" + search + "%"),
-            func.lower(User.last_name).like("%" + search + "%"))
-        query = query.filter(filter) \
-            .reset_joinpoint()
+            func.lower(User.last_name).like("%" + search + "%"),
+        )
+        query = query.filter(filter).reset_joinpoint()
 
     count = query.count()
     SORT_COLS = {
@@ -95,12 +105,12 @@ def users_dt_json():
     columns = list(SORT_COLS.get(sort_col, []))
     columns.extend([func.lower(User.last_name), func.lower(User.first_name)])
 
-    direction = asc if sort_dir == 'asc' else desc
-    order_by = map(direction, columns)
+    direction = asc if sort_dir == "asc" else desc
+    order_by = [direction(column) for column in columns]
 
     # sqlite does not support 'NULLS FIRST|LAST' in ORDER BY clauses
     engine = query.session.get_bind(User.__mapper__)
-    if engine.name != 'sqlite':
+    if engine.name != "sqlite":
         order_by[0] = nullslast(order_by[0])
 
     query = query.order_by(*order_by)
@@ -116,15 +126,16 @@ def users_dt_json():
         name = escape(getattr(user, "name") or "")
 
         cell0 = (
-            u'<a href="{url}"><img src="{src}" width="{size}" height="{size}">'
-            '</a>'.format(
-                url=user_url, src=mugshot, size=MUGSHOT_SIZE))
-        cell1 = (u'<div class="info"><a href="{user_url}">{name}</a> '
-                 u'</div>'.format(**locals()))
+            '<a href="{url}"><img src="{src}" width="{size}" height="{size}">'
+            "</a>".format(url=user_url, src=mugshot, size=MUGSHOT_SIZE)
+        )
+        cell1 = '<div class="info"><a href="{user_url}">{name}</a> ' "</div>".format(
+            **locals()
+        )
         cell2 = age(user.created_at)
         cell3 = age(user.last_active)
 
-        cell4 = ''  # TODO: follow / unfollow?
+        cell4 = ""  # TODO: follow / unfollow?
         data.append([cell0, cell1, cell2, cell3])
 
     result = {
@@ -137,16 +148,16 @@ def users_dt_json():
 
 
 @social.route("/users/<int:user_id>")
-@default_view(social, User, 'user_id')
+@default_view(social, User, "user_id")
 def user(user_id):
-    security = current_app.services['security']
+    security = get_service("security")
     user = User.query.get(user_id)
 
     # FIXME: use user profiles
     view_form = UserProfileViewForm(obj=user)
 
     communities = [m.community for m in user.communautes_membership]
-    if g.user != user and (not security.has_role(g.user, 'manager')):
+    if g.user != user and (not security.has_role(g.user, "manager")):
         # filter visible communautes (ticket 165)
         communities = [c for c in communities if c.has_member(g.user)]
 
@@ -154,34 +165,34 @@ def user(user_id):
 
     # FIXME
     contact = user
-    env = Env(user=user,
-              contact=contact,
-              view_form=view_form,
-              can_edit=can_edit(user),
-              tabs=make_tabs(user))
-
     entries = get_recent_entries(user=user)
     entries = ActivityEntryPresenter.wrap_collection(entries)
-    env.activity_entries = entries
-
-    return render_template("social/user.html", **env)
+    ctx = {
+        "user": user,
+        "contact": contact,
+        "view_form": view_form,
+        "can_edit": can_edit(user),
+        "tabs": make_tabs(user),
+        "activity_entries": entries,
+    }
+    return render_template("social/user.html", **ctx)
 
 
 def can_edit(user):
-    security = current_app.services.get('security')
+    security = get_service("security")
     if not security:
         return True
 
     # TODO: introduce a "self" role?
-    return (user == g.user) or security.has_role(g.user, 'admin')
+    return (user == g.user) or security.has_role(g.user, "admin")
 
 
 class UserProfileEdit(ObjectEdit):
 
     Model = User
     Form = UserProfileForm
-    pk = 'user_id'
-    _message_success = _l(u'Profile edited')
+    pk = "user_id"
+    _message_success = _l("Profile edited")
 
     def init_object(self, args, kwargs):
         args, kwargs = super(UserProfileEdit, self).init_object(args, kwargs)
@@ -189,7 +200,7 @@ class UserProfileEdit(ObjectEdit):
         return args, kwargs
 
     def view_url(self):
-        return url_for('.user', user_id=self.user.id)
+        return url_for(".user", user_id=self.user.id)
 
     def edit(self):
         if not can_edit(self.user):
@@ -199,26 +210,26 @@ class UserProfileEdit(ObjectEdit):
     def handle_commit_exception(self, exc):
         db.session.rollback()
         if isinstance(exc, sa.exc.IntegrityError):
-            log_msg = 'Error saving user profile'
+            log_msg = "Error saving user profile"
         else:
-            log_msg = 'Unexpected error while saving user profile'
-        logger.error(log_msg, exc_info=True, extra={'stack': True})
-        flash(_(u'Error occured'), "error")
+            log_msg = "Unexpected error while saving user profile"
+        logger.error(log_msg, exc_info=True, extra={"stack": True})
+        flash(_("Error occured"), "error")
         return self.redirect_to_view()
 
 
-social.route("/users/<int:user_id>/edit")(UserProfileEdit.as_view('user_edit'))
+social.route("/users/<int:user_id>/edit")(UserProfileEdit.as_view("user_edit"))
 
 
-@social.route("/users/<int:user_id>", methods=['POST'])
+@social.route("/users/<int:user_id>", methods=["POST"])
 def user_post(user_id):
     user = User.query.get(user_id)
-    action = request.form.get('action')
-    return_url = request.form.get('return_url')
+    action = request.form.get("action")
+    return_url = request.form.get("return_url")
 
-    if action == 'follow':
+    if action == "follow":
         g.user.follow(user)
-    elif action == 'unfollow':
+    elif action == "unfollow":
         g.user.unfollow(user)
     else:
         raise Exception("Should not happen")
@@ -241,30 +252,39 @@ def users_json():
     if not q or len(q) < 2:
         raise InternalServerError()
 
-    query = User.query \
-        .filter(or_(func.lower(User.first_name).like(q + "%"),
-                    func.lower(User.last_name).like(q + "%"))) \
-        .order_by(func.lower(User.last_name))
+    query = User.query.filter(
+        or_(
+            func.lower(User.first_name).like(q + "%"),
+            func.lower(User.last_name).like(q + "%"),
+        )
+    ).order_by(func.lower(User.last_name))
 
-    with_membership = request.args.get('with_membership')
+    with_membership = request.args.get("with_membership")
     if with_membership is not None:
         # provide membership info for a community
         with_membership = int(with_membership)
-        query = query \
-            .outerjoin(Membership,
-                       and_(Membership.user.expression,
-                            Membership.community_id == with_membership)) \
+        query = (
+            query.outerjoin(
+                Membership,
+                and_(
+                    Membership.user.expression,
+                    Membership.community_id == with_membership,
+                ),
+            )
+            .filter(User.can_login == True)
             .add_columns(Membership.role)
+        )
 
-    exclude_community = request.args.get('exclude_community')
+    exclude_community = request.args.get("exclude_community")
     if exclude_community is not None:
         exclude_community = int(exclude_community)
-        exclude = ~Membership.query \
-            .filter(Membership.user.expression,
-                    Membership.community_id == exclude_community) \
-            .options(sa.orm.noload('user'),
-                     sa.orm.noload('community')) \
+        exclude = (
+            ~Membership.query.filter(
+                Membership.user.expression, Membership.community_id == exclude_community
+            )
+            .options(sa.orm.noload("user"), sa.orm.noload("community"))
             .exists()
+        )
         query = query.filter(exclude)
 
     results = []
@@ -277,12 +297,12 @@ def users_json():
             role = text_type(role)
 
         item = {
-            'id': user.id,
-            'text': u'{} ({})'.format(user.name, user.email),
-            'name': user.name,
-            'email': user.email,
-            'role': role,
+            "id": user.id,
+            "text": "{} ({})".format(user.name, user.email),
+            "name": user.name,
+            "email": user.email,
+            "role": role,
         }
         results.append(item)
 
-    return jsonify({'results': results})
+    return jsonify({"results": results})
