@@ -1,50 +1,48 @@
 # coding=utf-8
-"""
-"""
-from __future__ import absolute_import
+""""""
+from __future__ import absolute_import, print_function, unicode_literals
 
 from datetime import date
 from itertools import groupby, islice
 
 import whoosh
 import whoosh.query as wq
+from abilian.services import get_service
+from abilian.web import url_for
+from abilian.web.action import actions
 from flask import current_app, g, render_template
 from flask_babel import format_date
+from six import text_type
 from sqlalchemy.orm import joinedload
 
 from abilian.sbe.apps.communities.blueprint import Blueprint
 from abilian.sbe.apps.documents.models import Document, icon_for
 from abilian.sbe.apps.forum.models import Thread
-from abilian.web import url_for
-from abilian.web.action import actions
 
 from .presenters import ActivityEntryPresenter
 from .util import get_recent_entries
 
-wall = Blueprint("wall",
-                 __name__,
-                 url_prefix="/wall",
-                 template_folder="templates")
+wall = Blueprint("wall", __name__, url_prefix="/wall", template_folder="templates")
 route = wall.route
 
 
 @wall.url_value_preprocessor
 def set_current_tab(endpoint, values):
-    g.current_tab = 'wall'
+    g.current_tab = "wall"
 
 
-@route('/')
+@route("/")
 def index():
-    actions.context['object'] = g.community._model
+    actions.context["object"] = g.community._model
     entries = get_recent_entries(20, community=g.community)
     entries = ActivityEntryPresenter.wrap_collection(entries)
     return render_template("wall/index.html", entries=entries)
 
 
-@route('/files')
+@route("/files")
 def files():
     community = g.community._model
-    actions.context['object'] = community
+    actions.context["object"] = community
 
     all_files = []
     if community.has_forum:
@@ -61,7 +59,6 @@ def files():
 
 
 class Attachment(object):
-
     def __init__(self, url, name, owner, date, content_length, content_type):
         self.url = url
         self.name = name
@@ -76,16 +73,18 @@ class Attachment(object):
 
 
 def get_attachments_from_forum(community):
-    all_threads = Thread.query \
-        .filter(Thread.community_id == community.id) \
-        .options(joinedload('posts')) \
-        .options(joinedload('posts.attachments')) \
-        .order_by(Thread.created_at.desc()).all()
+    all_threads = (
+        Thread.query.filter(Thread.community_id == community.id)
+        .options(joinedload("posts"))
+        .options(joinedload("posts.attachments"))
+        .order_by(Thread.created_at.desc())
+        .all()
+    )
 
     posts_with_attachments = []
     for thread in all_threads:
         for post in thread.posts:
-            if getattr(post, 'attachments', None):
+            if getattr(post, "attachments", None):
                 posts_with_attachments.append(post)
 
     posts_with_attachments.sort(key=lambda post: post.created_at)
@@ -95,9 +94,14 @@ def get_attachments_from_forum(community):
     for post in posts_with_attachments:
         for att in post.attachments:
             url = current_app.default_view.url_for(att)
-            attachment = Attachment(url, att.name, unicode(att.owner),
-                                    att.created_at, att.content_length,
-                                    att.content_type)
+            attachment = Attachment(
+                url,
+                att.name,
+                text_type(att.owner),
+                att.created_at,
+                att.content_length,
+                att.content_type,
+            )
             attachments.append(attachment)
 
     return attachments
@@ -105,18 +109,27 @@ def get_attachments_from_forum(community):
 
 # FIXME: significant performance issues here, needs major refactoring
 def get_attachments_from_dms(community):
-    svc = current_app.services['indexing']
-    filters = wq.And([wq.Term('community_id', community.id), wq.Term(
-        'object_type', Document.entity_type)])
-    sortedby = whoosh.sorting.FieldFacet('created_at', reverse=True)
-    documents = svc.search(u'', filter=filters, sortedby=sortedby, limit=50)
+    index_service = get_service("indexing")
+    filters = wq.And(
+        [
+            wq.Term("community_id", community.id),
+            wq.Term("object_type", Document.entity_type),
+        ]
+    )
+    sortedby = whoosh.sorting.FieldFacet("created_at", reverse=True)
+    documents = index_service.search("", filter=filters, sortedby=sortedby, limit=50)
 
     attachments = []
     for doc in documents:
         url = url_for(doc)
-        attachment = Attachment(url, doc['name'], doc['owner_name'],
-                                doc['created_at'], doc.get('content_length'),
-                                doc.get('content_type', u''))
+        attachment = Attachment(
+            url,
+            doc["name"],
+            doc["owner_name"],
+            doc["created_at"],
+            doc.get("content_length"),
+            doc.get("content_type", ""),
+        )
         attachments.append(attachment)
 
     return attachments
@@ -131,9 +144,10 @@ def group_monthly(objects):
 
     def format_month(year, month):
         month = format_date(date(year, month, 1), "MMMM").capitalize()
-        return u"%s %s" % (month, year)
+        return "%s %s" % (month, year)
 
     grouped = groupby(objects, grouper)
-    grouped = [(format_month(year, month), list(objs))
-               for (year, month), objs in grouped]
+    grouped = [
+        (format_month(year, month), list(objs)) for (year, month), objs in grouped
+    ]
     return grouped
