@@ -1,27 +1,30 @@
-from __future__ import absolute_import, print_function
+# coding=utf-8
+from __future__ import absolute_import, print_function, unicode_literals
+
+from abilian.web import url_for
 
 from abilian.sbe.testing import BaseTestCase
-from abilian.web import url_for
 
 
 class TestViews(BaseTestCase):
-    init_data = True
     no_login = True
 
     def test_all_registered_urls(self):
 
-        SKIP = frozenset([
-            'admin.audit_search_users',
-            'search.search_main',
-            'search.live',
-            'notifications.debug_social',
-            'social.groups_json',
-            'social.groups_new',
-            'social.users_json',
-            'social.users_dt_json',
-            'communities.community_default_image',
-            'images.user_default',
-        ])
+        SKIP = frozenset(
+            [
+                "admin.audit_search_users",
+                "search.search_main",
+                "search.live",
+                "notifications.debug_social",
+                "social.groups_json",
+                "social.groups_new",
+                "social.users_json",
+                "social.users_dt_json",
+                "communities.community_default_image",
+                "images.user_default",
+            ]
+        )
 
         rules = sorted(self.app.url_map.iter_rules(), key=lambda x: x.endpoint)
         for rule in rules:
@@ -42,15 +45,15 @@ class TestViews(BaseTestCase):
 
             url = url_for(rule.endpoint)
 
-            if '/ajax/' in url:
+            if "/ajax/" in url:
                 continue
 
             print(rule.endpoint, url)
 
             try:
                 response = self.client.get(url)
-                assert response.status_code in (200, 302), \
-                  "Bad link: {} (status={})".format(url, response.status_code)
-            except:
+                err_msg = "Bad link: {} (status={})".format(url, response.status_code)
+                assert response.status_code in (200, 302), err_msg
+            except BaseException:
                 print("Problem with url: {}".format(url))
                 raise
